@@ -16,7 +16,7 @@
 #include <string.h>
 
 #include "mm-common-telit.h"
-#include "mm-log.h"
+#include "mm-log-object.h"
 
 /*****************************************************************************/
 
@@ -49,63 +49,28 @@ telit_grab_port (MMPlugin *self,
     if (!g_str_equal (subsys, "tty"))
         goto out;
 
-    /* Look for port type hints; just probing can't distinguish which port should
-     * be the data/primary port on these devices.  We have to tag them based on
-     * what the Windows .INF files say the port layout should be.
-     *
-     * If no udev rules are found, AT#PORTCFG (if supported) can be used for
-     * identifying the port layout
-     */
-    if (mm_kernel_device_get_property_as_boolean (port, TAG_TELIT_MODEM_PORT)) {
-        mm_dbg ("telit: AT port '%s/%s' flagged as primary",
-                mm_port_probe_get_port_subsys (probe),
-                mm_port_probe_get_port_name (probe));
-        pflags = MM_PORT_SERIAL_AT_FLAG_PRIMARY;
-    } else if (mm_kernel_device_get_property_as_boolean (port, TAG_TELIT_AUX_PORT)) {
-        mm_dbg ("telit: AT port '%s/%s' flagged as secondary",
-                mm_port_probe_get_port_subsys (probe),
-                mm_port_probe_get_port_name (probe));
-        pflags = MM_PORT_SERIAL_AT_FLAG_SECONDARY;
-    } else if (mm_kernel_device_get_property_as_boolean (port, TAG_TELIT_NMEA_PORT)) {
-        mm_dbg ("telit: port '%s/%s' flagged as NMEA",
-                mm_port_probe_get_port_subsys (probe),
-                mm_port_probe_get_port_name (probe));
-        ptype = MM_PORT_TYPE_GPS;
-    } else if (g_object_get_data (G_OBJECT (device), TAG_GETPORTCFG_SUPPORTED) != NULL) {
-        if (g_strcmp0 (mm_kernel_device_get_property (port, "ID_USB_INTERFACE_NUM"), g_object_get_data (G_OBJECT (device), TAG_TELIT_MODEM_PORT)) == 0) {
-            mm_dbg ("telit: AT port '%s/%s' flagged as primary",
-                mm_port_probe_get_port_subsys (probe),
-                mm_port_probe_get_port_name (probe));
+    /* AT#PORTCFG (if supported) can be used for identifying the port layout */
+    if (g_object_get_data (G_OBJECT (device), TAG_GETPORTCFG_SUPPORTED) != NULL) {
+        guint usbif;
+
+        usbif = mm_kernel_device_get_property_as_int_hex (port, "ID_USB_INTERFACE_NUM");
+        if (usbif == GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (device), TAG_TELIT_MODEM_PORT))) {
+            mm_obj_dbg (self, "AT port '%s/%s' flagged as primary",
+                        mm_port_probe_get_port_subsys (probe),
+                        mm_port_probe_get_port_name (probe));
             pflags = MM_PORT_SERIAL_AT_FLAG_PRIMARY;
-        } else if (g_strcmp0 (mm_kernel_device_get_property (port, "ID_USB_INTERFACE_NUM"), g_object_get_data (G_OBJECT (device), TAG_TELIT_AUX_PORT)) == 0) {
-            mm_dbg ("telit: AT port '%s/%s' flagged as secondary",
-                mm_port_probe_get_port_subsys (probe),
-                mm_port_probe_get_port_name (probe));
+        } else if (usbif == GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (device), TAG_TELIT_AUX_PORT))) {
+            mm_obj_dbg (self, "AT port '%s/%s' flagged as secondary",
+                        mm_port_probe_get_port_subsys (probe),
+                        mm_port_probe_get_port_name (probe));
             pflags = MM_PORT_SERIAL_AT_FLAG_SECONDARY;
-        } else if (g_strcmp0 (mm_kernel_device_get_property (port, "ID_USB_INTERFACE_NUM"), g_object_get_data (G_OBJECT (device), TAG_TELIT_NMEA_PORT)) == 0) {
-            mm_dbg ("telit: port '%s/%s' flagged as NMEA",
-                mm_port_probe_get_port_subsys (probe),
-                mm_port_probe_get_port_name (probe));
+        } else if (usbif == GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (device), TAG_TELIT_NMEA_PORT))) {
+            mm_obj_dbg (self, "port '%s/%s' flagged as NMEA",
+                        mm_port_probe_get_port_subsys (probe),
+                        mm_port_probe_get_port_name (probe));
             ptype = MM_PORT_TYPE_GPS;
         } else
             ptype = MM_PORT_TYPE_IGNORED;
-    } else {
-        /* If the port isn't explicitly tagged as primary, secondary, or gps
-         * port, we will fallback to flagging it as secondary, but only if it
-         * probed AT successfully.
-         *
-         * This is so that we support the case where a single TTY is exposed
-         * by the modem and no explicit port type hint is specified.
-         *
-         * From the modem point of view, only the AT_FLAG_PRIMARY would be
-         * important, as that is the port that would end up getting used for PPP
-         * in this case, so having multiple secondary ports, if that ever
-         * happened, wouldn't be an issue.
-         */
-        if (mm_port_probe_is_at (probe))
-            pflags = MM_PORT_SERIAL_AT_FLAG_SECONDARY;
-        else
-            ptype = MM_PORT_TYPE_IGNORED;
     }
 
 out:
@@ -136,7 +101,8 @@ telit_custom_init_finish (MMPortProbe *probe,
 static void telit_custom_init_step (GTask *task);
 
 static gboolean
-cache_port_mode (MMDevice *device,
+cache_port_mode (MMPortProbe *probe,
+                 MMDevice    *device,
                  const gchar *reply)
 {
     GRegex *r = NULL;
@@ -154,7 +120,7 @@ cache_port_mode (MMDevice *device,
         goto out;
 
     if (!mm_get_uint_from_match_info (match_info, 2, &portcfg_current)) {
-        mm_dbg ("telit: unrecognized #PORTCFG <active> value");
+        mm_obj_dbg (probe, "unrecognized #PORTCFG <active> value");
         goto out;
     }
 
@@ -171,28 +137,26 @@ cache_port_mode (MMDevice *device,
     case 9:
     case 10:
     case 11:
-        g_object_set_data (G_OBJECT (device), TAG_TELIT_MODEM_PORT, "00");
-
+        g_object_set_data (G_OBJECT (device), TAG_TELIT_MODEM_PORT, GUINT_TO_POINTER (0x00));
         if (mm_device_get_product (device) == TELIT_GE910_FAMILY_PID)
-            g_object_set_data (G_OBJECT (device), TAG_TELIT_AUX_PORT, "02");
+            g_object_set_data (G_OBJECT (device), TAG_TELIT_AUX_PORT, GUINT_TO_POINTER (0x02));
         else
-            g_object_set_data (G_OBJECT (device), TAG_TELIT_AUX_PORT, "06");
+            g_object_set_data (G_OBJECT (device), TAG_TELIT_AUX_PORT, GUINT_TO_POINTER (0x06));
         break;
     case 2:
     case 3:
     case 6:
-        g_object_set_data (G_OBJECT (device), TAG_TELIT_MODEM_PORT, "00");
+        g_object_set_data (G_OBJECT (device), TAG_TELIT_MODEM_PORT, GUINT_TO_POINTER (0x00));
         break;
     case 8:
     case 12:
-        g_object_set_data (G_OBJECT (device), TAG_TELIT_MODEM_PORT, "00");
-
+        g_object_set_data (G_OBJECT (device), TAG_TELIT_MODEM_PORT, GUINT_TO_POINTER (0x00));
         if (mm_device_get_product (device) == TELIT_GE910_FAMILY_PID) {
-            g_object_set_data (G_OBJECT (device), TAG_TELIT_AUX_PORT, "02");
-            g_object_set_data (G_OBJECT (device), TAG_TELIT_NMEA_PORT, "04");
+            g_object_set_data (G_OBJECT (device), TAG_TELIT_AUX_PORT, GUINT_TO_POINTER (0x02));
+            g_object_set_data (G_OBJECT (device), TAG_TELIT_NMEA_PORT, GUINT_TO_POINTER (0x04));
         } else {
-            g_object_set_data (G_OBJECT (device), TAG_TELIT_AUX_PORT, "06");
-            g_object_set_data (G_OBJECT (device), TAG_TELIT_NMEA_PORT, "0a");
+            g_object_set_data (G_OBJECT (device), TAG_TELIT_AUX_PORT, GUINT_TO_POINTER (0x06));
+            g_object_set_data (G_OBJECT (device), TAG_TELIT_NMEA_PORT, GUINT_TO_POINTER (0x0a));
         }
         break;
     default:
@@ -205,8 +169,8 @@ out:
     g_match_info_free (match_info);
     g_regex_unref (r);
     if (error != NULL) {
-      mm_dbg ("telit: error while matching: %s", error->message);
-      g_error_free (error);
+        mm_obj_dbg (probe, "error while matching #PORTCFG: %s", error->message);
+        g_error_free (error);
     }
     return ret;
 }
@@ -226,8 +190,7 @@ getportcfg_ready (MMPortSerialAt *port,
 
     response = mm_port_serial_at_command_finish (port, res, &error);
     if (error) {
-        mm_dbg ("telit: couldn't get port mode: '%s'",
-                error->message);
+        mm_obj_dbg (probe, "couldn't get telit port mode: '%s'", error->message);
 
         /* If ERROR or COMMAND NOT SUPPORT occur then do not retry the
          * command.
@@ -243,8 +206,8 @@ getportcfg_ready (MMPortSerialAt *port,
 
         /* Results are cached in the parent device object */
         if (g_object_get_data (G_OBJECT (device), TAG_GETPORTCFG_SUPPORTED) == NULL) {
-            mm_dbg ("telit: retrieving port mode layout");
-            if (cache_port_mode (device, response)) {
+            mm_obj_dbg (probe, "retrieving telit port mode layout");
+            if (cache_port_mode (probe, device, response)) {
                 g_object_set_data (G_OBJECT (device), TAG_GETPORTCFG_SUPPORTED, GUINT_TO_POINTER (TRUE));
                 ctx->getportcfg_done = TRUE;
             }
@@ -279,8 +242,7 @@ telit_custom_init_step (GTask *task)
 
     /* If cancelled, end */
     if (g_cancellable_is_cancelled (g_task_get_cancellable (task))) {
-        mm_dbg ("telit: no need to keep on running custom init in (%s)",
-                mm_port_get_device (MM_PORT (ctx->port)));
+        mm_obj_dbg (probe, "no need to keep on running custom init");
         goto out;
     }
 
